from setuptools import setup

setup(
    name='danya',     
    version='0.7.1',         
    packages=['danya'], 
    description='Катаем всё!', 
    python_requires='>=3.6',
    include_package_data=True
)
